@@ -3,7 +3,7 @@
 
 import json
 
-from b2gperf import dzOptionParser, DatazillaPerfPoster
+from b2gperf import dzOptionParser, DatazillaPerfPoster, B2GPerfError
 from marionette import Marionette
 
 
@@ -20,29 +20,32 @@ class MozPerfHandler(DatazillaPerfPoster):
                 continue
 
             app_memory = '%s_memory' % app_name
-            results = { 'durations': {},
-                        'uss': { app_memory: [] },
-                        'pss': { app_memory: [] },
-                        'rss': { app_memory: [] },
-                        'vsize': { app_memory: [] },
-                        'system_uss': { app_memory: [] },
-                        'system_pss': { app_memory: [] },
-                        'system_rss': { app_memory: [] },
-                        'system_vsize': { app_memory: [] },
-                      }
+            results = {'durations': {},
+                       'uss': {app_memory: []},
+                       'pss': {app_memory: []},
+                       'rss': {app_memory: []},
+                       'vsize': {app_memory: []},
+                       'system_uss': {app_memory: []},
+                       'system_pss': {app_memory: []},
+                       'system_rss': {app_memory: []},
+                       'system_vsize': {app_memory: []}}
 
             for result in app_results.get('passes'):
                 metric = result['title'].strip().replace(' ', '_')
-                results['durations'].setdefault(metric, []).extend(result.get('mozPerfDurations'))
+                results['durations'].setdefault(metric, []).extend(
+                    result.get('mozPerfDurations'))
                 for perfmemory in result.setdefault('mozPerfMemory', []):
                     if perfmemory.get('app'):
                         for memory_metric in ('uss', 'pss', 'rss', 'vsize'):
                             if perfmemory['app'].get(memory_metric):
-                                results[memory_metric][app_memory].append(perfmemory['app'][memory_metric])
+                                results[memory_metric][app_memory].append(
+                                    perfmemory['app'][memory_metric])
                     if perfmemory.get('system'):
                         for memory_metric in ('uss', 'pss', 'rss', 'vsize'):
                             if perfmemory['system'].get(memory_metric):
-                                results['system_%s' % memory_metric][app_memory].append(perfmemory['system'][memory_metric])
+                                metric = results['system_%s' % memory_metric]
+                                metric[app_memory].append(
+                                    perfmemory['system'][memory_metric])
 
             if self.submit_report:
                 for item in results:
@@ -53,8 +56,20 @@ class MozPerfHandler(DatazillaPerfPoster):
                 for item in results:
                     print item, json.dumps(results[item])
 
-if __name__ == "__main__":
+
+def cli():
     parser = dzOptionParser(usage='%prog [options] result_file')
+    parser.add_option('--address',
+                      action='store',
+                      dest='address',
+                      default='localhost:2828',
+                      metavar='str',
+                      help='address of marionette server (default: %default)')
+    parser.add_option('--device-serial',
+                      action='store',
+                      dest='device_serial',
+                      metavar='str',
+                      help='serial identifier of device to target')
     options, args = parser.parse_args()
 
     if not args:
@@ -66,9 +81,19 @@ if __name__ == "__main__":
 
     datazilla_config = parser.datazilla_config(options)
 
-    marionette = Marionette(host='localhost', port=2828)
+    try:
+        host, port = options.address.split(':')
+    except ValueError:
+        raise B2GPerfError('--address must be in the format host:port')
+
+    marionette = Marionette(host=host, port=int(port))
     marionette.start_session()
     handler = MozPerfHandler(marionette,
                              datazilla_config=datazilla_config,
-                             sources=options.sources)
+                             sources=options.sources,
+                             device_serial=options.device_serial)
     handler.process_results(args[0])
+
+
+if __name__ == '__main__':
+    cli()
